<?php
/**
 * @package ablws
 * @version 1.0
 */
/**
* Plugin Name: Api Builder Lab WP Shortcode
* Plugin URI: https://www.apibuilderlab.com/documentation#wpshortcode
* Description: Integrating your form on apibuilderlab.com into your Wordpress Page.
* Version: 1.0
* Author: Eka Suryawan
* Author URI: https://apibuilderlab.com/
**/

if ( ! defined( 'ABSPATH' ) ) exit;

function ablws_httpapi($id, $key){
	$headkey = substr($key, -7);
	$body = array(
		'id'    => $id,
		'key'   => $key
	);
	$args = array(
		'body'        => $body,
		'timeout'     => '10',
		'redirection' => '5',
		'httpversion' => '1.0',
		'blocking'    => true,
		'headers'     => array(
			'x-access-token'	=>	'abl-wp-'.$headkey
		)
	);
	$response = wp_remote_post( 'https://app.apibuilderlab.com/wp/route/fields', $args );
	return $response;
}

function ablws_style(){
	wp_enqueue_style("abl_style_v1", plugins_url( 'assets/css/abl_custom.css', __FILE__ ), array(), "1.0", "all");
	wp_enqueue_style("timepicker", plugins_url( 'assets/css/jquery.datetimepicker.css', __FILE__ ), array(), "1.0", "all");
	wp_enqueue_script("jquery_js", plugins_url( 'assets/js/jquery.min.js', __FILE__ ), array(), "1.0", "all");
	wp_enqueue_script("phpdateformat", plugins_url( 'assets/js/php-date-formatter.min.js', __FILE__ ), array(), "1.0", "all");
	wp_enqueue_script("mousewheel", plugins_url( 'assets/js/jquery.mousewheel.js', __FILE__ ), array(), "1.0", "all");
	wp_enqueue_script("datetimepicker", plugins_url( 'assets/js/jquery.datetimepicker.js', __FILE__ ), array(), "1.0", "all");
	wp_enqueue_script("additional_js2", plugins_url( 'assets/js/script.js', __FILE__ ), array(), "1.0", "all");
}
add_action("wp_enqueue_scripts","ablws_style");

function ablws_script_footer() {
	?>
	<script type="text/javascript">
	  function ablws_submit_now(id){
		document.getElementById("abl_submit").disabled = true;
		var token = document.getElementById("abl_token").value;
		var formaction = "https://app.apibuilderlab.com/api/sendreq/"+id;
		const form = document.getElementById("abl_form_"+id);
		var formData = new FormData(form);
				const searchParams = new URLSearchParams(formData);
				const queryString = searchParams.toString();
				if (queryString.includes("file=")){
					var files = document.getElementById("file_"+id).files;
					formData.append("file", files[0]);
				}
		const xhttp = new XMLHttpRequest();
		xhttp.onload = function() {
			var response = this.responseText;
			var parseobj = JSON.parse(response);
			var textresponse = "";
			if (parseobj.error == true){
				textresponse = "<span class='abl_error'> <img src='<?php echo esc_html(plugins_url("/abl_wp_shortcode/assets/img/icons_error.png"));?>' width='20' style='position: relative;top: 3px;'> Error! <br>"+parseobj.message+"</span>";
			}else{
				textresponse = "<span class='abl_success'> <img src='<?php echo esc_html(plugins_url("/abl_wp_shortcode/assets/img/icon_check.png"));?>' width='20' style='position: relative;top: 3px;'> Thank you! Your submission was saved.</span>";
			}
			document.getElementById("abl_response_"+id).innerHTML = textresponse;
			form.reset();
			document.getElementById("abl_submit").disabled = false;
			return false;
		}
		xhttp.open("POST", formaction);
		xhttp.send(formData);
		return false;
	  }
	</script>
	<?php
}
add_action( 'wp_footer', 'ablws_script_footer' );

function ablws_shortcode( $atts ) {
	$a = shortcode_atts( array(
		'id' => 'xx',
        'key' => 'yy'
	), $atts );
	$field = ablws_httpapi($a['id'], $a['key']);
	if ($field != ""){
		$f = json_decode($field['body']);
		if ($f->error == 1){
			return "<br><p style='color: red;'>".$f->message."</p><br>";
		}else{
			$shortcode_return = "";
			foreach($f->fields as $row){
				$repname = str_replace("_", " ", $row->name);
				if (strpos($row->id, "aka_date") !== false){
					$shortcode_return .= '<label>'.$repname.'</label><br><input type="text" name="'.$row->id.'" class="abl_shcd node_date" placeholder="format: YYYY-MM-DD" required><br>';
				}else if (strpos($row->id, "aka_time") !== false){
					$shortcode_return .= '<label>'.$repname.'</label><br><input type="text" name="'.$row->id.'" class="abl_shcd node_datetime" placeholder="format: YYYY-MM-DD HH:MM:SS" required><br>';
				}else if (strpos($row->id, "_filemockpic") !== false){
					$shortcode_return .= '<label>'.$repname.'</label><br><input type="file" class="abl_shcd" name="file" id="file_'.$a['id'].'" placeholder="" required><br>';
				}else{
					if ( (strpos($repname, "Email") !== false) || (strpos($repname, "email") !== false) ){
						$shortcode_return .= '<label>'.$repname.'</label><br><input type="email" class="abl_shcd" name="'.$row->id.'" placeholder="" required><br>';
					}else{
						$shortcode_return .= '<label>'.$repname.'</label><br><input type="text" class="abl_shcd" name="'.$row->id.'" placeholder="" required><br>';
					}
				}
			}
			return '
			<form id="abl_form_'.$a['id'].'" method="POST" enctype="multipart/form-data" onsubmit="return ablws_submit_now('.$a['id'].')">
				<input type="hidden" name="token" id="abl_token" value="'.$a['key'].'">
				'.$shortcode_return.'
				<input type="submit" id="abl_submit" name="abl-submit" class="abl_btn_shcd" value="Submit">
			</form>
			<div id="abl_response_'.$a['id'].'"></div>
			';
		}
	}
	else{
		return "<br><p style='color: red;'>Connection lost to apibuilderlab.com!</p><br>";
	}
}
add_shortcode( 'ablws_shortcode', 'ablws_shortcode' );

function ablws_to_dashboard() {
	?>
	<style>
		.wrap_abl{ margin: 20px 20px 20px 0;}
		.wrap_abl .text-center{ text-align: center; }
		.wrap_abl h1{ font-weight: 700; font-family: 'Helvetica ,San-Serif'; font-size: 30px;margin: 0; line-height: 15px;}
		.wrap_abl p{ font-size: 16px;}
		.wrap_abl a{
			width: 100%;
			display: block;
			margin: 0 auto;
			outline: 0;
			background: purple;
			border: none;
			color: #fff;
			padding: 14px;
			border-radius: 37px;
			text-align: center;
			text-decoration: none;
			font-weight: 777;
			letter-spacing: 1px;
			box-sizing: border-box;
		}
		.wrap_abl a:hover{
			background: #c603c6;
		}
	</style>
	<div class="wrap_abl">
		<h1 class="text-center">Api Builder Lab</h1>
		<p class="text-center">Manage the API through apibuilderlab.com</p>
		<br>
		<a 
		href="https://app.apibuilderlab.com/dashboard"
		target="_blank">ACCESS DASHBOARD</a>
	</div>
	<?php
}

function ablws_admin_menus() {
    add_menu_page('ABL Shortcode', 'ABL Shortcode', 'manage_options', 
        'ablws_shortcode', 'ablws_to_dashboard');
}
add_action("admin_menu", "ablws_admin_menus");